@@ -17,6 +17,7 @@ from flask.wrappers import Response
 
 import jwt
 import boto3
+from botocore.exceptions import NoCredentialsError
 import flask
 import requests
 
@@ -186,7 +187,7 @@ def get_result_by_run(run_id, field=None, default_value=None):
                 result = result.get(field, default_value)
             return result
         elif storage_name == 'ceph':
-            s3 = get_s3_ceph()
+            s3 = get_ceph_resource()
             data = BytesIO()
             res_object = s3.Bucket(BUCKET_NAME).download_fileobj(Fileobj=data,Key=run_id)   
             res_object = data.getvalue()
@@ -225,13 +226,21 @@ def get_s3_client():
                         aws_secret_access_key=SECRET_ACCESS_KEY)
     
 
-def get_s3_ceph():
+def get_ceph_resource():
     return boto3.resource('s3',
                             endpoint_url=ENDPOINT_URL,
                             aws_access_key_id=ACCESS_KEY_ID,
                             aws_secret_access_key=SECRET_ACCESS_KEY)
 
 
+def get_ceph_client():
+    return boto3.client('s3',
+                          endpoint_url=ENDPOINT_URL,
+                          aws_access_key_id=ACCESS_KEY_ID,
+                          aws_secret_access_key=SECRET_ACCESS_KEY)
+
+
+
 def send_email(subject, from_email, to_emails, body, attachment=None):
     message = MIMEMultipart()
     message['Subject'] = subject
@@ -259,7 +268,7 @@ def send_email(subject, from_email, to_emails, body, attachment=None):
     return resp
 
 
-def upload_to_s3(content, location):
+def upload_to_storage(content, location):
     '''
     :param: content: bytes
     :param: location: str
@@ -279,10 +288,18 @@ def upload_to_s3(content, location):
             pass
     elif storage_name == 'ceph':
         try:
-            s3 = boto3.resource('s3',
-                                endpoint_url=ENDPOINT_URL,
-                                aws_access_key_id=ACCESS_KEY_ID,
-                                aws_secret_access_key=SECRET_ACCESS_KEY)
+            s3 = get_ceph_resource()
+            bucket_check = s3.Bucket(BUCKET_NAME) in s3.buckets.all()
+            
+            if bucket_check:
+                logging.info(f'{BUCKET_NAME} Bucket already exists!')
+            else:
+                logging.info(f'{BUCKET_NAME} Bucket does not exist!')
+                bucket = s3.Bucket(BUCKET_NAME)
+                bucket.create()
+                logger.info(f'{BUCKET_NAME} bucket created...')
+
+            
             s3.Bucket(BUCKET_NAME).put_object(Bucket=BUCKET_NAME,
                                             Key=location,
                                             Body=content)
@@ -305,7 +322,8 @@ def generate_pdf(analysis_run):
         'route': '/full-view',
         'token': get_token(),
         'app_id': APP_ID,
-        'size': 'A4'
+        'size': 'A4',
+        'storage': storage_name
     }
 
     api_proce_before_time = time.time()
@@ -314,8 +332,8 @@ def generate_pdf(analysis_run):
     api_proce_diff = diff_sec(api_proce_before_time, api_proce_after_time)
     if api_proce_diff > API_TIME_STACKS:
         logging.info('Pdf response is took %d (greater than %d) seconds', api_proce_diff, API_TIME_STACKS)
-    logger.info('Pdf response is: %s', res['key'])
-    return res['key']
+    logger.info('Pdf response is: %s', res['Key'])
+    return res['Key']
 
 
 
@@ -422,7 +440,7 @@ def upload_excel_s3(local_file, bucket, s3_file):
 #Upload excel file to ceph
 def upload_excel_ceph(local_file, bucket, s3_file):
     try:
-        s3 = get_s3_ceph()
+        s3 = get_ceph_resource()
         s3.Bucket(BUCKET_NAME).upload_file(Filename = local_file, Key = s3_file)
         logger.info('Upload successful')
         delete_excel_file(local_file)
@@ -441,7 +459,7 @@ def delete_excel_file(source_path):
         os.remove(source_path)
         logger.info('Excel file successfully deleted')
     except OSError as e:
-        logger.info(f'Failed to delete: %s : %s % {file_path, e.strerror}')
+        logger.info(f'Failed to delete: %s : %s % {source_path, e.strerror}')
 
 
 #Generate excel file
@@ -451,10 +469,12 @@ def generate_excel_file(run_id, orgId, report_gen_start_time, report_gen_complet
     reportname = f"{APP_ID.lower()}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
     filepath = './' + reportname
     generate_excel(run_id, orgId, excel_data, report_gen_start_time, report_gen_completed_time, filepath)
-    excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/xls/' + reportname
+    # excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/xls/' + reportname
     if storage_name == 's3':
+        excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/xls/' + reportname
         excel_url = upload_excel_s3(filepath, BUCKET_NAME, excel_file_location)
     elif storage_name == 'ceph':
+        excel_file_location = f'{APP_ID.lower()}/{run_id}/xls/' + reportname
         excel_url = upload_excel_ceph(filepath, BUCKET_NAME, excel_file_location)
     else:
         logger.info("No storages are found")
@@ -464,7 +484,7 @@ def generate_excel_file(run_id, orgId, report_gen_start_time, report_gen_complet
 def init_mail(org_id, run_id):
     logger.info('Entered into init_mail method')
     try:
-        url = BASE_API_URL + f'/analytics/api/v3/tenants/{org_id}/send'
+        url = BASE_API_URL + f'/analytics/api/v3/tenants/{org_id}/sends'
         data={
                 "runId" : run_id
             }
@@ -485,4 +505,4 @@ def upload_excel(analysis_run, excel_file):
     timestamp = datetime.now().strftime("%Y-%m-%d-%H-%M-%S")
     s3_path = f'{analysis_run.analysis.app.slug}/excel/{timestamp}.xlsx'
 
-    return upload_to_s3(excel_file, s3_path)
+    return upload_to_storage(excel_file, s3_path)
